==> plugins4.0-1.48.0-sources.jar: com/af/plugins/AESUtil.java <==
package com.af.plugins;


import org.apache.commons.lang3.StringUtils;

import javax.crypto.Cipher;
import javax.crypto.KeyGenerator;
import javax.crypto.spec.SecretKeySpec;
import java.math.BigInteger;

/**
 * AES的加密和解密
 */
public class AESUtil {
    //算法
    private static final String ALGORITHMSTR = "AES/ECB/PKCS5Padding";

    /**
     * 加密方法
     * @param content 待加密的内容
     * @param encryptKey 加密密钥
     * @return 加密后的字符串
     */
    public static String encrypt(String content, String encryptKey) {
        try {
            return aesEncrypt(content, encryptKey);
        } catch (Exception e) {
            e.printStackTrace();
            return "";
        }
    }

    /**
     * 解密方法
     * @param content 待解密的内容
     * @param encryptKey 解密密钥
     * @return 解密后的字符串
     */
    public static String decrypt(String content, String encryptKey) {
        try {
            return aesDecrypt(content, encryptKey);
        } catch (Exception e) {
            e.printStackTrace();
            return "";
        }
    }

    /**
     * 将byte[]转为各种进制的字符串
     * @param bytes byte[]
     * @param radix 可以转换进制的范围，从Character.MIN_RADIX到Character.MAX_RADIX，超出范围后变为10进制
     * @return 转换后的字符串
     */
    public static String binary(byte[] bytes, int radix){
        return new BigInteger(1, bytes).toString(radix);// 这里的1代表正数
    }

    /**
     * AES加密
     * @param content 待加密的内容
     * @param encryptKey 加密密钥
     * @return 加密后的byte[]
     * @throws Exception
     */
    public static byte[] aesEncryptToBytes(String content, String encryptKey) throws Exception {
        KeyGenerator kgen = KeyGenerator.getInstance("AES");
        kgen.init(128);
        Cipher cipher = Cipher.getInstance(ALGORITHMSTR);
        cipher.init(Cipher.ENCRYPT_MODE, new SecretKeySpec(encryptKey.getBytes(), "AES"));

        return cipher.doFinal(content.getBytes("utf-8"));
    }

    /**
     * AES加密为base 64 code
     * @param content 待加密的内容
     * @param encryptKey 加密密钥
     * @return 加密后的base 64 code
     * @throws Exception
     */
    public static String aesEncrypt(String content, String encryptKey) throws Exception {
        return Base64Utils.encode(aesEncryptToBytes(content, encryptKey));
    }

    /**
     * AES解密
     * @param encryptBytes 待解密的byte[]
     * @param decryptKey 解密密钥
     * @return 解密后的String
     * @throws Exception
     */
    public static String aesDecryptByBytes(byte[] encryptBytes, String decryptKey) throws Exception {
        KeyGenerator kgen = KeyGenerator.getInstance("AES");
        kgen.init(128);

        Cipher cipher = Cipher.getInstance(ALGORITHMSTR);
        cipher.init(Cipher.DECRYPT_MODE, new SecretKeySpec(decryptKey.getBytes(), "AES"));
        byte[] decryptBytes = cipher.doFinal(encryptBytes);
        return new String(decryptBytes, "UTF-8");
    }

    /**
     * 将base 64 code AES解密
     * @param encryptStr 待解密的base 64 code
     * @param decryptKey 解密密钥
     * @return 解密后的string
     * @throws Exception
     */
    public static String aesDecrypt(String encryptStr, String decryptKey) throws Exception {
        return StringUtils.isEmpty(encryptStr) ? null : aesDecryptByBytes(Base64Utils.decodeBuffer(encryptStr), decryptKey);
    }
}

==> plugins4.0-1.54.15-sources.jar: com/af/plugins/AESUtil.java <==
package com.af.plugins;


import com.aote.util.JsonHelper;
import org.apache.commons.lang3.StringUtils;
import org.json.JSONObject;

import javax.crypto.Cipher;
import javax.crypto.KeyGenerator;
import javax.crypto.spec.SecretKeySpec;
import java.math.BigInteger;

/**
 * AES的加密和解密
 */
public class AESUtil {
    //算法
    private static final String ALGORITHMSTR = "AES/ECB/PKCS5Padding";

    /**
     * 加密方法
     * @param content 待加密的内容
     * @param encryptKey 加密密钥
     * @return 加密后的字符串
     */
    public static String encrypt(String content, String encryptKey) {
        try {
            return aesEncrypt(content, encryptKey);
        } catch (Exception e) {
            e.printStackTrace();
            return "";
        }
    }

    /**
     * 解密方法
     * @param content 待解密的内容
     * @param encryptKey 解密密钥
     * @return 解密后的字符串
     */
    public static String decrypt(String content, String encryptKey) {
        try {
            return aesDecrypt(content, encryptKey);
        } catch (Exception e) {
            e.printStackTrace();
            return "";
        }
    }

    /**
     * 将byte[]转为各种进制的字符串
     * @param bytes byte[]
     * @param radix 可以转换进制的范围，从Character.MIN_RADIX到Character.MAX_RADIX，超出范围后变为10进制
     * @return 转换后的字符串
     */
    public static String binary(byte[] bytes, int radix){
        return new BigInteger(1, bytes).toString(radix);// 这里的1代表正数
    }

    /**
     * AES加密
     * @param content 待加密的内容
     * @param encryptKey 加密密钥
     * @return 加密后的byte[]
     * @throws Exception
     */
    public static byte[] aesEncryptToBytes(String content, String encryptKey) throws Exception {
        KeyGenerator kgen = KeyGenerator.getInstance("AES");
        kgen.init(128);
        Cipher cipher = Cipher.getInstance(ALGORITHMSTR);
        cipher.init(Cipher.ENCRYPT_MODE, new SecretKeySpec(encryptKey.getBytes(), "AES"));

        return cipher.doFinal(content.getBytes("utf-8"));
    }

    /**
     * AES加密为base 64 code
     * @param content 待加密的内容
     * @param encryptKey 加密密钥
     * @return 加密后的base 64 code
     * @throws Exception
     */
    public static String aesEncrypt(String content, String encryptKey) throws Exception {
        return Base64Utils.encode(aesEncryptToBytes(content, encryptKey));
    }

    /**
     * AES解密
     * @param encryptBytes 待解密的byte[]
     * @param decryptKey 解密密钥
     * @return 解密后的String
     * @throws Exception
     */
    public static String aesDecryptByBytes(byte[] encryptBytes, String decryptKey) throws Exception {
        KeyGenerator kgen = KeyGenerator.getInstance("AES");
        kgen.init(128);

        Cipher cipher = Cipher.getInstance(ALGORITHMSTR);
        cipher.init(Cipher.DECRYPT_MODE, new SecretKeySpec(decryptKey.getBytes(), "AES"));
        byte[] decryptBytes = cipher.doFinal(encryptBytes);
        return new String(decryptBytes, "UTF-8");
    }

    /**
     * 将base 64 code AES解密
     * @param encryptStr 待解密的base 64 code
     * @param decryptKey 解密密钥
     * @return 解密后的string
     * @throws Exception
     */
    public static String aesDecrypt(String encryptStr, String decryptKey) throws Exception {
        return StringUtils.isEmpty(encryptStr) ? null : aesDecryptByBytes(Base64Utils.decodeBuffer(encryptStr), decryptKey);
    }

    /**
     * 从后台config.json配置加密
     * */
    public static String addDecrypt(String paramStr){
        // 数据加密
//       configJson=={"proxy":"http://127.0.0.1:8300","ldap":"http://127.0.0.1:8300","encryKey":"OXuYieBb4eoIne^K","isEncrypt":true}
        JSONObject configJson = JsonHelper.getConfig();
//        JSONObject configJson = new JSONObject();
//        configJson.put("isEncrypt","true");
//        configJson.put("encryKey","OXuYieBb4eoIne^K");
//        String  o =configJson.getString("isEncrypt");

//        System.out.println("mm--"+encryKey);
        if (configJson.has("isEncrypt")&&configJson.getBoolean("isEncrypt") ||
                configJson.has("isNeed")&&configJson.getBoolean("isNeed")) {
//            System.out.println("加密串"+paramStr);
//            System.out.println("加密key=="+encryKey);
//            System.out.println("加密后--"+decrypt(paramStr, encryKey));
            String encryKey = configJson.getString("encryKey");
            return AESUtil.encrypt(paramStr, encryKey);
        }else{
//            System.out.println("未加密--"+paramStr);
            return paramStr;
        }
    }
    public static String getEncrypt(String str){
        // 数据解密
        JSONObject configJson = JsonHelper.getConfig();
//        System.out.println("密key=="+encryKey);
//        String  o = configJson.getString("isEncrypt");
//        System.out.println("configJson=="+configJson.has("isEncrypt"));
//        System.out.println("configJson=="+configJson.getBoolean("isEncrypt"));
        if (configJson.has("isEncrypt")&&configJson.getBoolean("isEncrypt") ||
                configJson.has("isNeed")&&configJson.getBoolean("isNeed")) {
            String encryKey = configJson.getString("encryKey");
            return decrypt(str, encryKey);
        }else{
            return str;
        }
    }
}
